def find_free_network_port() -> int:
    """
    Finds a free port on localhost. It is useful in single-node training
    when we don't want to connect to a real master node but have to set the `MASTER_PORT` environment variable.

    Returns:
        an available local port
    """
    import socket
    s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    s.bind(("", 0))
    s.listen(1)
    port = s.getsockname()[1]
    s.close()
    return port
